==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/AttributeReferenceInClassSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ReferringClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferringClassInAssocSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.AttributeReferenceInClass;
import io.ciera.tool.sql.ooaofooa.subsystem.AttributeReferenceInClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferentialAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferredToIdentifierAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.AttributeReferenceInClassSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ReferentialAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ReferredToIdentifierAttributeSetImpl;

import java.util.Arrays;
import java.util.List;


public class AttributeReferenceInClassSetImpl extends InstanceSet<AttributeReferenceInClassSet,AttributeReferenceInClass> implements AttributeReferenceInClassSet {

    // attributes
    @Override
    public void setRel_Name( String m_Rel_Name ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRel_Name( m_Rel_Name );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setDescrip( m_Descrip );
    }
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setRAttr_ID( UniqueId ref_RAttr_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRAttr_ID( ref_RAttr_ID );
    }
    @Override
    public void setIs_Cstrd( boolean m_Is_Cstrd ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setIs_Cstrd( m_Is_Cstrd );
    }
    @Override
    public void setROid_ID( int ref_ROid_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setROid_ID( ref_ROid_ID );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setRObj_ID( UniqueId ref_RObj_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRObj_ID( ref_RObj_ID );
    }
    @Override
    public void setPARef_ID( UniqueId ref_PARef_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setPARef_ID( ref_PARef_ID );
    }
    @Override
    public void setRObj_Name( String m_RObj_Name ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRObj_Name( m_RObj_Name );
    }
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setARef_ID( UniqueId m_ARef_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setARef_ID( m_ARef_ID );
    }
    @Override
    public void setROIR_ID( UniqueId ref_ROIR_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setROIR_ID( ref_ROIR_ID );
    }
    @Override
    public void setRAttr_Name( String m_RAttr_Name ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRAttr_Name( m_RAttr_Name );
    }


    // selections
    @Override
    public ReferentialAttributeSet R108_is_resolved_by_ReferentialAttribute() throws XtumlException {
        ReferentialAttributeSet referentialattributeset = new ReferentialAttributeSetImpl();
        for ( AttributeReferenceInClass attributereferenceinclass : this ) referentialattributeset.add( attributereferenceinclass.R108_is_resolved_by_ReferentialAttribute() );
        return referentialattributeset;
    }
    @Override
    public ReferringClassInAssocSet R111_is_used_to_refer_class_by_ReferringClassInAssoc() throws XtumlException {
        ReferringClassInAssocSet referringclassinassocset = new ReferringClassInAssocSetImpl();
        for ( AttributeReferenceInClass attributereferenceinclass : this ) referringclassinassocset.add( attributereferenceinclass.R111_is_used_to_refer_class_by_ReferringClassInAssoc() );
        return referringclassinassocset;
    }
    @Override
    public ReferredToIdentifierAttributeSet R111_refers_across_association_via_ReferredToIdentifierAttribute() throws XtumlException {
        ReferredToIdentifierAttributeSet referredtoidentifierattributeset = new ReferredToIdentifierAttributeSetImpl();
        for ( AttributeReferenceInClass attributereferenceinclass : this ) referredtoidentifierattributeset.add( attributereferenceinclass.R111_refers_across_association_via_ReferredToIdentifierAttribute() );
        return referredtoidentifierattributeset;
    }
    @Override
    public AttributeReferenceInClassSet R112_precedes_AttributeReferenceInClass() throws XtumlException {
        AttributeReferenceInClassSet attributereferenceinclassset = new AttributeReferenceInClassSetImpl();
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclassset.add( attributereferenceinclass.R112_precedes_AttributeReferenceInClass() );
        return attributereferenceinclassset;
    }
    @Override
    public AttributeReferenceInClassSet R112_succeeds_AttributeReferenceInClass() throws XtumlException {
        AttributeReferenceInClassSet attributereferenceinclassset = new AttributeReferenceInClassSetImpl();
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclassset.add( attributereferenceinclass.R112_succeeds_AttributeReferenceInClass() );
        return attributereferenceinclassset;
    }


    @Override
    public AttributeReferenceInClass nullElement() {
        return AttributeReferenceInClassImpl.EMPTY_ATTRIBUTEREFERENCEINCLASS;
    }

    @Override
    public AttributeReferenceInClassSet emptySet() {
      return new AttributeReferenceInClassSetImpl();
    }

    @Override
    public AttributeReferenceInClassSet value() {
        return this;
    }

    @Override
    public List<AttributeReferenceInClass> elements() {
        return Arrays.asList(toArray(new AttributeReferenceInClass[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/AttributeReferenceInClassSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ReferringClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferringClassInAssocSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.AttributeReferenceInClass;
import io.ciera.tool.sql.ooaofooa.subsystem.AttributeReferenceInClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferentialAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ReferredToIdentifierAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.AttributeReferenceInClassSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ReferentialAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ReferredToIdentifierAttributeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class AttributeReferenceInClassSetImpl extends InstanceSet<AttributeReferenceInClassSet,AttributeReferenceInClass> implements AttributeReferenceInClassSet {

    public AttributeReferenceInClassSetImpl() {
    }

    public AttributeReferenceInClassSetImpl(Comparator<? super AttributeReferenceInClass> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setROIR_ID( UniqueId ref_ROIR_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setROIR_ID( ref_ROIR_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setRAttr_Name( String m_RAttr_Name ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRAttr_Name( m_RAttr_Name );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setDescrip( m_Descrip );
    }
    @Override
    public void setRObj_ID( UniqueId ref_RObj_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRObj_ID( ref_RObj_ID );
    }
    @Override
    public void setRObj_Name( String m_RObj_Name ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRObj_Name( m_RObj_Name );
    }
    @Override
    public void setRAttr_ID( UniqueId ref_RAttr_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRAttr_ID( ref_RAttr_ID );
    }
    @Override
    public void setPARef_ID( UniqueId ref_PARef_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setPARef_ID( ref_PARef_ID );
    }
    @Override
    public void setAttr_ID( UniqueId ref_Attr_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setAttr_ID( ref_Attr_ID );
    }
    @Override
    public void setRel_Name( String m_Rel_Name ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRel_Name( m_Rel_Name );
    }
    @Override
    public void setARef_ID( UniqueId m_ARef_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setARef_ID( m_ARef_ID );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setROid_ID( int ref_ROid_ID ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setROid_ID( ref_ROid_ID );
    }
    @Override
    public void setIs_Cstrd( boolean m_Is_Cstrd ) throws XtumlException {
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclass.setIs_Cstrd( m_Is_Cstrd );
    }


    // selections
    @Override
    public ReferentialAttributeSet R108_is_resolved_by_ReferentialAttribute() throws XtumlException {
        ReferentialAttributeSet referentialattributeset = new ReferentialAttributeSetImpl();
        for ( AttributeReferenceInClass attributereferenceinclass : this ) referentialattributeset.add( attributereferenceinclass.R108_is_resolved_by_ReferentialAttribute() );
        return referentialattributeset;
    }
    @Override
    public ReferringClassInAssocSet R111_is_used_to_refer_class_by_ReferringClassInAssoc() throws XtumlException {
        ReferringClassInAssocSet referringclassinassocset = new ReferringClassInAssocSetImpl();
        for ( AttributeReferenceInClass attributereferenceinclass : this ) referringclassinassocset.add( attributereferenceinclass.R111_is_used_to_refer_class_by_ReferringClassInAssoc() );
        return referringclassinassocset;
    }
    @Override
    public ReferredToIdentifierAttributeSet R111_refers_across_association_via_ReferredToIdentifierAttribute() throws XtumlException {
        ReferredToIdentifierAttributeSet referredtoidentifierattributeset = new ReferredToIdentifierAttributeSetImpl();
        for ( AttributeReferenceInClass attributereferenceinclass : this ) referredtoidentifierattributeset.add( attributereferenceinclass.R111_refers_across_association_via_ReferredToIdentifierAttribute() );
        return referredtoidentifierattributeset;
    }
    @Override
    public AttributeReferenceInClassSet R112_precedes_AttributeReferenceInClass() throws XtumlException {
        AttributeReferenceInClassSet attributereferenceinclassset = new AttributeReferenceInClassSetImpl();
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclassset.add( attributereferenceinclass.R112_precedes_AttributeReferenceInClass() );
        return attributereferenceinclassset;
    }
    @Override
    public AttributeReferenceInClassSet R112_succeeds_AttributeReferenceInClass() throws XtumlException {
        AttributeReferenceInClassSet attributereferenceinclassset = new AttributeReferenceInClassSetImpl();
        for ( AttributeReferenceInClass attributereferenceinclass : this ) attributereferenceinclassset.add( attributereferenceinclass.R112_succeeds_AttributeReferenceInClass() );
        return attributereferenceinclassset;
    }


    @Override
    public AttributeReferenceInClass nullElement() {
        return AttributeReferenceInClassImpl.EMPTY_ATTRIBUTEREFERENCEINCLASS;
    }

    @Override
    public AttributeReferenceInClassSet emptySet() {
      return new AttributeReferenceInClassSetImpl();
    }

    @Override
    public AttributeReferenceInClassSet emptySet(Comparator<? super AttributeReferenceInClass> comp) {
      return new AttributeReferenceInClassSetImpl(comp);
    }

    @Override
    public AttributeReferenceInClassSet value() {
        return this;
    }

    @Override
    public List<AttributeReferenceInClass> elements() {
        return Arrays.asList(toArray(new AttributeReferenceInClass[0]));
    }

}
